@@ -409,8 +409,9 @@ if ($do==1) {
    ($stdout,$stderr)=$handle->cmd("${sudo}make install",'__display__');
    ($stdout,$stderr)=$handle->cwd("..");
 }
-$do=0;
+$do=1;
 if ($do==1) { # NGINX
+print "DOING NGINX\n";
    # https://nealpoole.com/blog/2011/04/setting-up-php-fastcgi-and-nginx
    #    -dont-trust-the-tutorials-check-your-configuration/
    # https://www.digitalocean.com/community/tutorials/
@@ -434,7 +435,7 @@ if ($do==1) { # NGINX
    my $zlib='zlib-1.2.8';
    ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
       "http://zlib.net/$zlib.tar.gz",'__display__');
-   my $checksum='44d667c142d7cda120332623eab69f40';
+   $checksum='44d667c142d7cda120332623eab69f40';
    ($stdout,$stderr)=$handle->cmd("md5sum -c - <<<\"$checksum $zlib.tar.gz\"",
       '__display__');
    unless ($stderr) {
@@ -449,10 +450,10 @@ if ($do==1) { # NGINX
    ($stdout,$stderr)=$handle->cmd("tar xvf $zlib.tar.gz",'__display__');
    my $ossl='openssl-1.0.2g';
    $checksum='36af23887402a5ea4ebef91df8e61654906f58f2';
-   ($stdout,$stderr)=$handle->cmd(
+   ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
       "https://www.openssl.org/source/$ossl.tar.gz",
       '__display__');
-   ($stdout,$stderr)=$handle->cmd("shasum -c - <<<\"$checksum $ossl.tar.gz\"",
+   ($stdout,$stderr)=$handle->cmd("sha1sum -c - <<<\"$checksum $ossl.tar.gz\"",
       '__display__');
    unless ($stderr) {
       print(qq{ + CHECKSUM Test for $ossl *PASSED* \n});
@@ -469,18 +470,17 @@ if ($do==1) { # NGINX
                   '--conf-path=/usr/local/nginx/nginx.conf '.
                   '--pid-path=/usr/local/nginx/nginx.pid '.
                   "--with-http_ssl_module --with-pcre=objs/lib/$pcre ".
-                  '--with-zlib=objs/lib/$zlib';
+                  "--with-zlib=objs/lib/$zlib";
    ($stdout,$stderr)=$handle->cmd($make_nginx,'__display__');
    ($stdout,$stderr)=$handle->cmd("make install",'__display__');
    ($stdout,$stderr)=$handle->cmd("sed -i 's/1024/64/' ".
       "/usr/local/nginx/nginx.conf");
    $ad="%NL%".
-       "%NL%            include fastcgi_params; # We'll discuss this later".
+       "%NL%            include fastcgi_params;".
        "%NL%            fastcgi_pass  localhost:3003;%NL%%NL%";
-   ($stdout,$stderr)=$handle->cmd("sed -i \'/location \/ \{/a$ad\' ".
+   ($stdout,$stderr)=$handle->cmd("sed -i \'/location/i$ad\' ".
       "/usr/local/nginx/nginx.conf");
-   $ad='%NL%'.
-       '%NL%        location /static {'.
+   $ad='%NL%        location /static {'.
        '%NL%            root /home/Administrator/FullAutoAPI/root;'.
        '%NL%        }%NL%%NL%';
    ($stdout,$stderr)=$handle->cmd(
@@ -563,7 +563,7 @@ exit;
    while (1) {
       my $output.=Net::FullAuto::FA_Core::fetch($handle);
       last if $output=~/$prompt/;
-      print $output;
+      print 'm'.$output;
       if (-1<index $output,'possible automatically') {
          $handle->{_cmd_handle}->print('yes');
          $output='';
@@ -2263,9 +2263,8 @@ END
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
       "./script/fullautoapi_fastcgi.pl");
    ($stdout,$stderr)=$handle->cmd("${sudo}ldconfig");
-print "GOING TO START WEB SERVER\n";
    $handle->{_cmd_handle}->print(
-      "${sudo}script/fullautoapi_fastcgi.pl -p 3001 &");
+      "${sudo}script/fullautoapi_fastcgi.pl -l localhost:3003 &");
    $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
    while (1) {
       my $output.=Net::FullAuto::FA_Core::fetch($handle);
@@ -2282,7 +2281,7 @@ print "GOING TO START WEB SERVER\n";
    }
    sleep 15;
    print "\n   ACCESS CATALYST REST EXAMPLE AT:\n\n",
-         " http://localhost:3001\n";
+         " http://localhost\n";
    my $thanks=<<'END';
 
      ______                  _    ,
